@@ -10,10 +10,10 @@ Unless required by applicable law or agreed to in writing, software distributed
 an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 specific language governing permissions and limitations under the License.
 """
-import os
-from prometheus_client import start_http_server
 
 
 def start_metrics_http_server():
-    port = int(os.getenv("METRICS_SERVER_PORT", "5001"))
-    start_http_server(port)
+    from prometheus_client import start_http_server  # noqa
+
+    print("start metrics http server listen :5001")
+    start_http_server(port=5001)
